@@ -27,6 +27,7 @@
 
 using System;
 using System.Collections;
+using System.Collections.Generic;
 using System.IO;
 
 using Beagle.Util;
@@ -62,7 +63,18 @@ namespace Beagle.Daemon.KMailQueryable {
 		public KMailQueryable Queryable {
 		    get { return queryable; }
 		}
-		
+
+		////////////// Progress tracking //////////////////
+
+		private double progress = 0;
+
+		internal double Progress {
+			set { progress = value; }
+			get { return progress; }
+		}
+
+		///////////////////////////////////////////////////
+
 		private string lastGoodDirPath = ""; // cache last successful directory
 
 		public KMailIndexer (KMailQueryable queryable, string account, string root)
@@ -71,15 +83,16 @@ namespace Beagle.Daemon.KMailQueryable {
 			account_name = account;
 			mail_root = root;
 			mail_directories = new ArrayList ();
-			Logger.Log.Debug ("mail_directories created for:" + mail_root + " (" + mail_directories.Count + ")");
 			folder_directories = new ArrayList ();
 			mbox_files = new ArrayList ();
 
 			excludes = new ArrayList ();
-			excludes.Add ("spam");
-			excludes.Add ("outbox");
-			excludes.Add ("trash");
-			excludes.Add ("drafts");
+			List<string[]> values = Conf.Daemon.GetListOptionValues (Conf.Names.ExcludeMailfolder);
+			if (values == null)
+				return;
+
+			foreach (string[] item in values)
+				excludes.Add (item [0].ToLower ());
 		}
 
 		/**
@@ -91,13 +104,6 @@ namespace Beagle.Daemon.KMailQueryable {
 					     string srcpath,
 					     Inotify.EventType type)
 		{
-			//FIXME this case should NEVER occur, still it does
-			if (mail_directories == null) {
-				Logger.Log.Debug ("*** WEIRD AVIRAM CASE for :" + mail_root);
-				Logger.Log.Debug ("Received inotify event{3} for {4}: path={0}, subitem={1}, srcpath={2}", path, subitem, srcpath, type, mail_root);
-				return;
-			}
-			
 			if (subitem == "")
 				return;
 			string fullPath = Path.Combine (path, subitem);
@@ -109,7 +115,7 @@ namespace Beagle.Daemon.KMailQueryable {
 			// - if is in one of the mail_directories, index it if it is an mbox file
 			if ((type & Inotify.EventType.Create) != 0 && (type & Inotify.EventType.IsDirectory) == 0) {
 				if (IsMailDir (path)) {
-					Indexable indexable = MaildirMessageToIndexable (fullPath);
+					Indexable indexable = MaildirMessageToIndexable (fullPath, false);
 					AddIndexableTask (indexable, fullPath);
 				} else {
 					// add mbox file to mbox_files
@@ -141,14 +147,14 @@ namespace Beagle.Daemon.KMailQueryable {
 			// - need to delete from the source
 			if ((type & Inotify.EventType.MovedTo) != 0 && (type & Inotify.EventType.IsDirectory) == 0) {
 				if (IsMailDir (path)) {
-					Indexable indexable = MaildirMessageToIndexable (fullPath);
+					Indexable indexable = MaildirMessageToIndexable (fullPath, false);
 					AddIndexableTask (indexable, fullPath);
 				}
 				if (IsMailDir (srcpath))
 					RemoveMail (srcpath);
 				if (mbox_files.Contains (fullPath)) {
 					// check if this because of compaction, in which case need to delete previous mbox
-					if (srcpath.EndsWith ("." + subitem + ".compacted"))
+					if (srcpath != null && srcpath.EndsWith ("." + subitem + ".compacted"))
 						RemoveMbox (fullPath);
 					// FIXME need to ensure IndexMbox is scheduled *after* RemoveMbox finishes
 					// RemoveMbox creates a job with immediate priority while
@@ -159,7 +165,7 @@ namespace Beagle.Daemon.KMailQueryable {
 				return;
 			}
 
-			// Case: file is modified
+			// Case: file is modified i.e. there was no create event but closewrite event
 			// - possibly some mbox was changed
 			// FIXME kmail doesnt physically delete the deleted mails from mbox files unless compacted
 			// - which means one has to read the .index files to find deleted messages...
@@ -359,7 +365,7 @@ namespace Beagle.Daemon.KMailQueryable {
 		/** 
 		 * Create an indexable from a maildir message
 		 */
-		public Indexable MaildirMessageToIndexable (string filename)
+		public Indexable MaildirMessageToIndexable (string filename, bool crawl)
 		{
 			//Logger.Log.Debug ("+ indexing maildir mail:" + filename);
 			String folder = GetFolderMaildir(filename);
@@ -368,7 +374,8 @@ namespace Beagle.Daemon.KMailQueryable {
 			Indexable indexable = new Indexable (file_uri);
 			indexable.HitType = "MailMessage";
 			indexable.MimeType = "message/rfc822";
-			indexable.CacheContent = false;
+			indexable.CacheContent = true;
+			indexable.FlushBufferCache = crawl;
 
 			indexable.AddProperty (Property.NewUnsearched ("fixme:client", "kmail"));
 			indexable.AddProperty (Property.NewUnsearched ("fixme:account", account_name));
@@ -393,7 +400,7 @@ namespace Beagle.Daemon.KMailQueryable {
 			indexable.Timestamp = message.Date.ToUniversalTime ();
 			indexable.HitType = "MailMessage";
 			indexable.MimeType = "message/rfc822";
-			indexable.CacheContent = false;
+			indexable.CacheContent = true;
 
 			indexable.AddProperty (Property.NewUnsearched ("fixme:client", "kmail"));
 			indexable.AddProperty (Property.NewUnsearched ("fixme:account", account_name));
@@ -473,7 +480,7 @@ namespace Beagle.Daemon.KMailQueryable {
 		 */
 		public bool IsMailDir (string dirPath)
 		{
-			if (! (dirPath.EndsWith("cur") || dirPath.EndsWith("new")))
+			if (dirPath == null || ! (dirPath.EndsWith("cur") || dirPath.EndsWith("new")))
 				return false;
 
 			string possibleMaildir = (Directory.GetParent (dirPath)).FullName;
