@@ -7,6 +7,7 @@
 
 using System;
 using System.Collections;
+using System.Collections.Generic;
 using System.Diagnostics;
 
 using Gtk;
@@ -46,6 +47,7 @@ namespace Beagle.Search {
 		private Beagle.Search.ScopeType scope = ScopeType.Everything;
 		private Beagle.Search.SortType sort = SortType.Modified;
 		private Beagle.Search.TypeFilter filter = null;
+		private QueryDomain domain = QueryDomain.Local;
 
 		// Whether we should grab focus from the text entry
 		private bool grab_focus = false;
@@ -242,7 +244,8 @@ namespace Beagle.Search {
 				TotalMatches = 0;
 
 				current_query = new Query ();
-				current_query.AddDomain (QueryDomain.Neighborhood);
+				current_query.QueryDomain = domain;
+
 				current_query.AddText (query);
 				current_query.HitsAddedEvent += OnHitsAdded;
 				current_query.HitsSubtractedEvent += OnHitsSubtracted;
@@ -363,17 +366,12 @@ namespace Beagle.Search {
 		
 		private void OnDomainChanged (QueryDomain domain, bool active)
 		{
-			if (current_query == null)
-				return;
-			
-			// FIXME: Most likely refire the query.
-			// Also keep the setting, so it can be used for future queries
-			// in this running instance.
-			
 			if (active)
-				current_query.AddDomain (domain);
+				this.domain |= domain;
 			else
-				current_query.RemoveDomain (domain);
+				this.domain &= ~domain;
+
+			// FIXME: Most likely refire the query.
 		}
 		
 		private void ShowInformation (Tiles.Tile tile)
