@@ -97,7 +97,6 @@ public class SettingsDialog
 
         [Widget] ScrolledWindow networking_sw;
 
-#if ENABLE_AVAHI
         [Widget] Alignment networking_password_box;
 
         [Widget] CheckButton require_password_toggle;
@@ -105,7 +104,6 @@ public class SettingsDialog
         [Widget] Entry index_name_entry;
         [Widget] Entry password_entry;
 
-#endif
         [Widget] Button add_host_button;
         
         private NetworkingView networking_view;
@@ -146,9 +144,11 @@ public class SettingsDialog
                 networking_sw.Child = networking_view;
 		networking_box.Show ();
 
-#if ENABLE_AVAHI
 		networking_settings_box.Visible = true;
-#endif  
+
+		//FIXME Password feature is not yet implemented
+		networking_password_box.Sensitive = false;
+		require_password_toggle.Sensitive = false;
 
 		LoadConfiguration ();
 
@@ -173,9 +173,12 @@ public class SettingsDialog
 			case "--indexing":
 				notebook.Page = 1;
 				return;
-			case "--networking":
+			case "--backends":
 				notebook.Page = 2;
 				return;
+			case "--networking":
+				notebook.Page = 3;
+				return;
 			}
 		}
 	}
@@ -248,13 +251,11 @@ public class SettingsDialog
 			}
 		}
 
-#if ENABLE_AVAHI
                 require_password_toggle.Active = networking_config.GetOption (Conf.Names.PasswordRequired, true);
                 index_name_entry.Text = networking_config.GetOption (Conf.Names.ServiceName, String.Empty);
                 string password = networking_config.GetOption (Conf.Names.ServicePassword, String.Empty);
 		password = password.PadRight (12);
                 password_entry.Text = password.Substring (0, 12);
-#endif
 
 		values = daemon_config.GetListOptionValues (Conf.Names.DeniedBackends);
 		if (values != null)
@@ -312,11 +313,9 @@ public class SettingsDialog
 
 		networking_config.SetOption ("WebInterface", allow_webinterface_toggle.Active);
 		networking_config.SetOption (Conf.Names.ServiceEnabled, allow_global_access_toggle.Active);
-#if ENABLE_AVAHI
 		networking_config.SetOption (Conf.Names.ServiceName, index_name_entry.Text);
 		networking_config.SetOption (Conf.Names.PasswordRequired, require_password_toggle.Active);
 		networking_config.SetOption (Conf.Names.ServicePassword, Password.Encode (password_entry.Text));
-#endif
 
 		List<string[]> svcs = new List<string[]> (networking_view.Nodes.Count);
 		foreach (NetworkService svc in networking_view.Nodes) {
@@ -421,11 +420,9 @@ public class SettingsDialog
 		reader.Close ();
 
 		if (! enabled) {
-			// FIXME: gnome-session has a bug in which autostart overrides
-			// break if Hidden=true is set.
-			writer.WriteLine ("# FIXME: Hidden=true has to be commented out for GNOME autostart to be");
-			writer.WriteLine ("# disabled, but KDE requires it to disable autostart.");
-			writer.WriteLine ("#Hidden=true");
+			writer.WriteLine ("# Setting Hidden=true unintuitively disables autostart on KDE and");
+			writer.WriteLine ("# GNOME >= 2.19.2, but it breaks disabling of autostart in older GNOME.");
+			writer.WriteLine ("Hidden=true");
 			writer.WriteLine ("X-GNOME-Autostart-enabled=false");
 		}
 
@@ -439,11 +436,9 @@ public class SettingsDialog
 		reader.Close ();
 
 		if (! enabled) {
-			// FIXME: gnome-session has a bug in which autostart overrides
-			// break if Hidden=true is set.
-			writer.WriteLine ("# FIXME: Hidden=true has to be commented out for GNOME autostart to be");
-			writer.WriteLine ("# disabled, but KDE requires it to disable autostart.");
-			writer.WriteLine ("#Hidden=true");
+			writer.WriteLine ("# Setting Hidden=true unintuitively disables autostart on KDE and");
+			writer.WriteLine ("# GNOME >= 2.19.2, but it breaks disabling of autostart in older GNOME.");
+			writer.WriteLine ("Hidden=true");
 			writer.WriteLine ("X-GNOME-Autostart-enabled=false");
 		}
 
@@ -639,7 +634,7 @@ public class SettingsDialog
                                                               DialogFlags.Modal,
                                                               MessageType.Warning,
                                                               ButtonsType.Ok,
-                                                              Catalog.GetString ("Netbeagle Node not added"),
+                                                              Catalog.GetString ("Remote beagle host not added"),
                                                               error_message);
                 } else {
                         foreach (NetworkService node in new_nodes)
@@ -674,16 +669,13 @@ public class SettingsDialog
 	
 	private void OnGlobalAccessToggled (object o, EventArgs args)
 	{
-#if ENABLE_AVAHI
 		networking_settings_box.Sensitive = allow_global_access_toggle.Active;
-#endif  
 	}
 	
 	private void OnRequirePasswordToggled (object o, EventArgs args)
 	{
-#if ENABLE_AVAHI
-		networking_password_box.Sensitive = require_password_toggle.Active;
-#endif
+		//FIXME Passwords for remote beagled is not yet implemented
+		//networking_password_box.Sensitive = require_password_toggle.Active;
 	}
 
 	////////////////////////////////////////////////////////////////
@@ -887,14 +879,14 @@ public class SettingsDialog
 			column.Title = Catalog.GetString ("Name");
 			CellRendererText renderer = new CellRendererText ();
 			column.PackStart (renderer, true);
-			column.SetCellDataFunc (renderer, NameCellFunc);
+			column.SetCellDataFunc (renderer, new TreeCellDataFunc (NameCellFunc));
 			AppendColumn (column);
 
                         column = new TreeViewColumn ();
                         column.Title = Catalog.GetString ("Address");
                         renderer = new CellRendererText ();
                         column.PackStart (renderer, true);
-                        column.SetCellDataFunc (renderer, AddressCellFunc);
+                        column.SetCellDataFunc (renderer, new TreeCellDataFunc (AddressCellFunc));
                         AppendColumn (column);
 		
 		}
@@ -1315,9 +1307,6 @@ public class SettingsDialog
 		}
 	}
 
-
-#if ENABLE_AVAHI
-
         ////////////////////////////////////////////////////////////////
         // PasswordDialog
 
@@ -1342,7 +1331,6 @@ public class SettingsDialog
                         Present ();
                 }
         }
-#endif
 
         ////////////////////////////////////////////////////////////////
         // AddHostDialog
@@ -1454,6 +1442,9 @@ public class SettingsDialog
                                 icon_view.Visible = false;
                                 mdns_radio_button.Visible = false;
 #endif  
+
+			// FIXME Password for remote host is not yet implemented
+			password_entry.Sensitive = false;
                 }
                 
                 private void CreateStore ()
@@ -1584,31 +1575,45 @@ public class SettingsDialog
 			"NetworkServices", // This should be configurable in the network tab
 			"Opera",
 			"Pidgin",
-			"Tomboy"
+			"Tomboy",
+			/* System-wide indexes */
+			"applications",
+			"documentation",
+			"manpages",
+			"Locate",
+			"monodoc",
+			"windows"
 		};
 
 		private string[] descriptions = new string[] {
-			"Evolution's mail.",
-			"Evolution's address book, memos and tasks.",
-			"Thunderbird's email.",
-			"RSS feeds from Akregator.",
-			"RSS feeds from Blam.",
-			"Files and folders on the local file system.",
-			"Mail messages from KMail.",
-			"Notes from KNotes.",
-			"Agenda from KOrganizer.",
-			"Contacts from KAddressBook.",
-			"Konqueror's bookmarks.",
-			"Konqueror's history.",
-			"IMs and chats from Konversation.",
-			"IMs and chats from Kopete",
-			"Mind-maps from Labyrinth.",
-			"RSS feeds from Liferea.",
-			"Nautilus' metadata (emblems, notes, etc.)",
-			"Search other search services in the network (EXPERIMENTAL)",
-			"Opera's bookmarks and browsing history.",
-			"IMs and chats from Pidgin.",
-			"Notes from Tomboy."
+			Catalog.GetString ("Evolution's mail."),
+			Catalog.GetString ("Evolution's address book, memos and tasks."),
+			Catalog.GetString ("Thunderbird's email."),
+			Catalog.GetString ("RSS feeds from Akregator."),
+			Catalog.GetString ("RSS feeds from Blam."),
+			Catalog.GetString ("Files and folders on the local file system."),
+			Catalog.GetString ("Mail messages from KMail."),
+			Catalog.GetString ("Notes from KNotes."),
+			Catalog.GetString ("Agenda from KOrganizer."),
+			Catalog.GetString ("Contacts from KAddressBook."),
+			Catalog.GetString ("Konqueror's bookmarks."),
+			Catalog.GetString ("Konqueror's history."),
+			Catalog.GetString ("IMs and chats from Konversation."),
+			Catalog.GetString ("IMs and chats from Kopete"),
+			Catalog.GetString ("Mind-maps from Labyrinth."),
+			Catalog.GetString ("RSS feeds from Liferea."),
+			Catalog.GetString ("Nautilus' metadata (emblems, notes, etc.)"),
+			Catalog.GetString ("Search other search services in the network (EXPERIMENTAL)"),
+			Catalog.GetString ("Opera's bookmarks and browsing history."),
+			Catalog.GetString ("IMs and chats from Pidgin."),
+			Catalog.GetString ("Notes from Tomboy."),
+			/* System-wide indexes */
+			Catalog.GetString ("(System) Applications"),
+			Catalog.GetString ("(System) Help files"),
+			Catalog.GetString ("(System) Manual pages"),
+			Catalog.GetString ("(System) Supplementary search results using 'locate' command"),
+			Catalog.GetString ("(System) Mono documentation"),
+			Catalog.GetString ("(System) Files from Windows' partition")
 		};
 
 		public BackendView ()
@@ -1625,7 +1630,7 @@ public class SettingsDialog
 			base.AppendColumn (Catalog.GetString ("Description"), new CellRendererText (), "markup", 2);
 
 			for (int i = 0; i < backends.Length; i++)
-				store.AppendValues (true, backends [i], "<i>" + Catalog.GetString (descriptions [i]) + "</i>");
+				store.AppendValues (true, backends [i], "<i>" + descriptions [i] + "</i>");
 		}
 
 		public void Set (string backend, bool enabled)
